@@ -26,9 +26,11 @@ import org.gcube.data.analysis.tabulardata.model.datatype.IntegerType;
 import org.gcube.data.analysis.tabulardata.model.datatype.NumericType;
 import org.gcube.data.analysis.tabulardata.model.datatype.TextType;
 import org.gcube.data.analysis.tabulardata.model.metadata.Locales;
+import org.gcube.data.analysis.tabulardata.model.table.Table;
 import org.gcube.data.analysis.tabulardata.model.table.TableId;
 import org.gcube.data.analysis.tabulardata.model.time.PeriodType;
 import org.gcube.data.analysis.tabulardata.service.TabularDataService;
+import org.gcube.data.analysis.tabulardata.service.exception.NoSuchTableException;
 import org.gcube.data.analysis.tabulardata.service.impl.TabularDataServiceFactory;
 import org.gcube.data.analysis.tabulardata.service.template.TemplateId;
 import org.slf4j.Logger;
@@ -167,7 +169,7 @@ public class TemplateService {
 		try{
 			ScopeProvider.instance.set(scope);
 			logger.info("Saving template with parameter: name: "+ name+", description: "+ description+", agency: "+ template+", template: "+ template);
-			AuthorizationProvider.instance.set(new AuthorizationToken(username));
+			AuthorizationProvider.instance.set(new AuthorizationToken(username, scope));
 			logger.info("Username is: "+ username+", scope is: "+ scope);
 			return service.saveTemplate(name, description, agency, template);
 		}catch (Exception e) {
@@ -179,7 +181,7 @@ public class TemplateService {
 		try{
 			ScopeProvider.instance.set(scope);
 			logger.info("Updating template id: "+templateId+ ", template: "+ template);
-			AuthorizationProvider.instance.set(new AuthorizationToken(username));
+			AuthorizationProvider.instance.set(new AuthorizationToken(username, scope));
 			logger.info("Username is: "+ username+", scope is: "+ scope);
 			return service.update(new TemplateId(templateId), template);
 		}catch (Exception e) {
@@ -196,7 +198,7 @@ public class TemplateService {
 	
 		try{
 			ScopeProvider.instance.set(scope);
-			AuthorizationProvider.instance.set(new AuthorizationToken(username));
+			AuthorizationProvider.instance.set(new AuthorizationToken(username,scope));
 			return service.getTemplates();
 		}catch (Exception e) {
 			throw new Exception("Sorry, an error occurred on getting templates ",e);
@@ -209,7 +211,7 @@ public class TemplateService {
 		try{
 			logger.info("Getting TemplateDescription...");
 			ScopeProvider.instance.set(scope);
-			AuthorizationProvider.instance.set(new AuthorizationToken(username));
+			AuthorizationProvider.instance.set(new AuthorizationToken(username,scope));
 			return service.getTemplate(new TemplateId(templateId));
 		}catch (Exception e) {
 			throw new Exception("Sorry, an error occurred on getting template by id: "+templateId,e);
@@ -221,10 +223,17 @@ public class TemplateService {
 		try{
 			logger.info("Getting Tabular Resources...");
 			ScopeProvider.instance.set(scope);
-			AuthorizationProvider.instance.set(new AuthorizationToken(username));
+			AuthorizationProvider.instance.set(new AuthorizationToken(username,scope));
 			return service.getTabularResources();
 		}catch (Exception e) {
 			throw new Exception("Sorry, an error occurred on getting Tabular Resources: ",e);
 		}
 	}
+	
+	public Table getTable(TableId tableId) throws NoSuchTableException{
+		logger.info("Getting Table...");
+		ScopeProvider.instance.set(scope);
+		AuthorizationProvider.instance.set(new AuthorizationToken(username,scope));
+		return service.getTable(tableId);
+	}
 }
